# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['TriggerActionArgs', 'TriggerAction']

@pulumi.input_type
class TriggerActionArgs:
    def __init__(__self__, *,
                 action_id: pulumi.Input[str],
                 trigger: pulumi.Input[str],
                 display_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a TriggerAction resource.
        :param pulumi.Input[str] action_id: The ID of the action to bind to the trigger.
        :param pulumi.Input[str] trigger: The ID of the trigger to bind with. Available options: `post-login`, `credentials-exchange`, `pre-user-registration`, `post-user-registration`, `post-change-password`, `send-phone-message`, `password-reset-post-challenge`, `iga-approval`, `iga-certification`, `iga-fulfillment-assignment`, `iga-fulfillment-execution`.
        :param pulumi.Input[str] display_name: The name for this action within the trigger. This can be useful for distinguishing between multiple instances of the same action bound to a trigger. Defaults to action name when not provided.
        """
        pulumi.set(__self__, "action_id", action_id)
        pulumi.set(__self__, "trigger", trigger)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)

    @property
    @pulumi.getter(name="actionId")
    def action_id(self) -> pulumi.Input[str]:
        """
        The ID of the action to bind to the trigger.
        """
        return pulumi.get(self, "action_id")

    @action_id.setter
    def action_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "action_id", value)

    @property
    @pulumi.getter
    def trigger(self) -> pulumi.Input[str]:
        """
        The ID of the trigger to bind with. Available options: `post-login`, `credentials-exchange`, `pre-user-registration`, `post-user-registration`, `post-change-password`, `send-phone-message`, `password-reset-post-challenge`, `iga-approval`, `iga-certification`, `iga-fulfillment-assignment`, `iga-fulfillment-execution`.
        """
        return pulumi.get(self, "trigger")

    @trigger.setter
    def trigger(self, value: pulumi.Input[str]):
        pulumi.set(self, "trigger", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for this action within the trigger. This can be useful for distinguishing between multiple instances of the same action bound to a trigger. Defaults to action name when not provided.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)


@pulumi.input_type
class _TriggerActionState:
    def __init__(__self__, *,
                 action_id: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 trigger: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering TriggerAction resources.
        :param pulumi.Input[str] action_id: The ID of the action to bind to the trigger.
        :param pulumi.Input[str] display_name: The name for this action within the trigger. This can be useful for distinguishing between multiple instances of the same action bound to a trigger. Defaults to action name when not provided.
        :param pulumi.Input[str] trigger: The ID of the trigger to bind with. Available options: `post-login`, `credentials-exchange`, `pre-user-registration`, `post-user-registration`, `post-change-password`, `send-phone-message`, `password-reset-post-challenge`, `iga-approval`, `iga-certification`, `iga-fulfillment-assignment`, `iga-fulfillment-execution`.
        """
        if action_id is not None:
            pulumi.set(__self__, "action_id", action_id)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if trigger is not None:
            pulumi.set(__self__, "trigger", trigger)

    @property
    @pulumi.getter(name="actionId")
    def action_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the action to bind to the trigger.
        """
        return pulumi.get(self, "action_id")

    @action_id.setter
    def action_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action_id", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for this action within the trigger. This can be useful for distinguishing between multiple instances of the same action bound to a trigger. Defaults to action name when not provided.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def trigger(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the trigger to bind with. Available options: `post-login`, `credentials-exchange`, `pre-user-registration`, `post-user-registration`, `post-change-password`, `send-phone-message`, `password-reset-post-challenge`, `iga-approval`, `iga-certification`, `iga-fulfillment-assignment`, `iga-fulfillment-execution`.
        """
        return pulumi.get(self, "trigger")

    @trigger.setter
    def trigger(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "trigger", value)


class TriggerAction(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_id: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 trigger: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        With this resource, you can bind an action to a trigger. Once an action is created and deployed, it can be attached (i.e. bound) to a trigger so that it will be executed as part of a flow.

        Ordering of an action within a specific flow is not currently supported when using this resource; the action will get appended to the end of the flow. To precisely manage ordering, it is advised to either do so with the dashboard UI or with the `auth0_trigger_bindings` resource.

        !> This resource appends an action to the trigger binding. In contrast, the `TriggerActions` resource manages all
        the action bindings to a trigger. To avoid potential issues, it is recommended not to use this resource in conjunction
        with the `TriggerAction` resource when binding actions to the same trigger.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        login_alert = auth0.Action("login_alert",
            name="Alert after login",
            code=\"\"\"exports.onContinuePostLogin = async (event, api) => {
          console.log("foo");
        };"
        \"\"\",
            deploy=True,
            supported_triggers=auth0.ActionSupportedTriggersArgs(
                id="post-login",
                version="v3",
            ))
        post_login_alert_action = auth0.TriggerAction("post_login_alert_action",
            trigger="post-login",
            action_id=login_alert.id)
        ```

        ## Import

        This resource can be imported by specifying the

        trigger and action ID separated by "::" (note the double colon)

        <trigger>::<actionID>

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/triggerAction:TriggerAction post_login_action "post-login::28b5c8fa-d371-5734-acf6-d0cf80ead918"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action_id: The ID of the action to bind to the trigger.
        :param pulumi.Input[str] display_name: The name for this action within the trigger. This can be useful for distinguishing between multiple instances of the same action bound to a trigger. Defaults to action name when not provided.
        :param pulumi.Input[str] trigger: The ID of the trigger to bind with. Available options: `post-login`, `credentials-exchange`, `pre-user-registration`, `post-user-registration`, `post-change-password`, `send-phone-message`, `password-reset-post-challenge`, `iga-approval`, `iga-certification`, `iga-fulfillment-assignment`, `iga-fulfillment-execution`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TriggerActionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        With this resource, you can bind an action to a trigger. Once an action is created and deployed, it can be attached (i.e. bound) to a trigger so that it will be executed as part of a flow.

        Ordering of an action within a specific flow is not currently supported when using this resource; the action will get appended to the end of the flow. To precisely manage ordering, it is advised to either do so with the dashboard UI or with the `auth0_trigger_bindings` resource.

        !> This resource appends an action to the trigger binding. In contrast, the `TriggerActions` resource manages all
        the action bindings to a trigger. To avoid potential issues, it is recommended not to use this resource in conjunction
        with the `TriggerAction` resource when binding actions to the same trigger.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        login_alert = auth0.Action("login_alert",
            name="Alert after login",
            code=\"\"\"exports.onContinuePostLogin = async (event, api) => {
          console.log("foo");
        };"
        \"\"\",
            deploy=True,
            supported_triggers=auth0.ActionSupportedTriggersArgs(
                id="post-login",
                version="v3",
            ))
        post_login_alert_action = auth0.TriggerAction("post_login_alert_action",
            trigger="post-login",
            action_id=login_alert.id)
        ```

        ## Import

        This resource can be imported by specifying the

        trigger and action ID separated by "::" (note the double colon)

        <trigger>::<actionID>

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/triggerAction:TriggerAction post_login_action "post-login::28b5c8fa-d371-5734-acf6-d0cf80ead918"
        ```

        :param str resource_name: The name of the resource.
        :param TriggerActionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TriggerActionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_id: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 trigger: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TriggerActionArgs.__new__(TriggerActionArgs)

            if action_id is None and not opts.urn:
                raise TypeError("Missing required property 'action_id'")
            __props__.__dict__["action_id"] = action_id
            __props__.__dict__["display_name"] = display_name
            if trigger is None and not opts.urn:
                raise TypeError("Missing required property 'trigger'")
            __props__.__dict__["trigger"] = trigger
        super(TriggerAction, __self__).__init__(
            'auth0:index/triggerAction:TriggerAction',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action_id: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            trigger: Optional[pulumi.Input[str]] = None) -> 'TriggerAction':
        """
        Get an existing TriggerAction resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action_id: The ID of the action to bind to the trigger.
        :param pulumi.Input[str] display_name: The name for this action within the trigger. This can be useful for distinguishing between multiple instances of the same action bound to a trigger. Defaults to action name when not provided.
        :param pulumi.Input[str] trigger: The ID of the trigger to bind with. Available options: `post-login`, `credentials-exchange`, `pre-user-registration`, `post-user-registration`, `post-change-password`, `send-phone-message`, `password-reset-post-challenge`, `iga-approval`, `iga-certification`, `iga-fulfillment-assignment`, `iga-fulfillment-execution`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TriggerActionState.__new__(_TriggerActionState)

        __props__.__dict__["action_id"] = action_id
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["trigger"] = trigger
        return TriggerAction(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="actionId")
    def action_id(self) -> pulumi.Output[str]:
        """
        The ID of the action to bind to the trigger.
        """
        return pulumi.get(self, "action_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        The name for this action within the trigger. This can be useful for distinguishing between multiple instances of the same action bound to a trigger. Defaults to action name when not provided.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def trigger(self) -> pulumi.Output[str]:
        """
        The ID of the trigger to bind with. Available options: `post-login`, `credentials-exchange`, `pre-user-registration`, `post-user-registration`, `post-change-password`, `send-phone-message`, `password-reset-post-challenge`, `iga-approval`, `iga-certification`, `iga-fulfillment-assignment`, `iga-fulfillment-execution`.
        """
        return pulumi.get(self, "trigger")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['UserRolesArgs', 'UserRoles']

@pulumi.input_type
class UserRolesArgs:
    def __init__(__self__, *,
                 roles: pulumi.Input[Sequence[pulumi.Input[str]]],
                 user_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a UserRoles resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: Set of IDs of roles assigned to the user.
        :param pulumi.Input[str] user_id: ID of the user.
        """
        pulumi.set(__self__, "roles", roles)
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Set of IDs of roles assigned to the user.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[str]:
        """
        ID of the user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _UserRolesState:
    def __init__(__self__, *,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering UserRoles resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: Set of IDs of roles assigned to the user.
        :param pulumi.Input[str] user_id: ID of the user.
        """
        if roles is not None:
            pulumi.set(__self__, "roles", roles)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Set of IDs of roles assigned to the user.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_id", value)


class UserRoles(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        With this resource, you can manage assigned roles for a user.

        !> This resource manages all the roles assigned to a user. In contrast, the `UserRole` resource only appends a
        role to a user. To avoid potential issues, it is recommended not to use this resource in conjunction with the
        `UserRole` resource when managing roles for the same user id.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # Example:
        admin = auth0.Role("admin",
            name="admin",
            description="Administrator")
        user = auth0.User("user",
            connection_name="Username-Password-Authentication",
            username="unique_username",
            name="Firstname Lastname",
            email="test@test.com",
            password="passpass$12$12")
        user_roles = auth0.UserRoles("user_roles",
            user_id=user.id,
            roles=[admin.id])
        ```

        ## Import

        This resource can be imported using the user ID.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/userRoles:UserRoles user_roles "auth0|111111111111111111111111"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: Set of IDs of roles assigned to the user.
        :param pulumi.Input[str] user_id: ID of the user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserRolesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        With this resource, you can manage assigned roles for a user.

        !> This resource manages all the roles assigned to a user. In contrast, the `UserRole` resource only appends a
        role to a user. To avoid potential issues, it is recommended not to use this resource in conjunction with the
        `UserRole` resource when managing roles for the same user id.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # Example:
        admin = auth0.Role("admin",
            name="admin",
            description="Administrator")
        user = auth0.User("user",
            connection_name="Username-Password-Authentication",
            username="unique_username",
            name="Firstname Lastname",
            email="test@test.com",
            password="passpass$12$12")
        user_roles = auth0.UserRoles("user_roles",
            user_id=user.id,
            roles=[admin.id])
        ```

        ## Import

        This resource can be imported using the user ID.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/userRoles:UserRoles user_roles "auth0|111111111111111111111111"
        ```

        :param str resource_name: The name of the resource.
        :param UserRolesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserRolesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserRolesArgs.__new__(UserRolesArgs)

            if roles is None and not opts.urn:
                raise TypeError("Missing required property 'roles'")
            __props__.__dict__["roles"] = roles
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
        super(UserRoles, __self__).__init__(
            'auth0:index/userRoles:UserRoles',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            user_id: Optional[pulumi.Input[str]] = None) -> 'UserRoles':
        """
        Get an existing UserRoles resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: Set of IDs of roles assigned to the user.
        :param pulumi.Input[str] user_id: ID of the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserRolesState.__new__(_UserRolesState)

        __props__.__dict__["roles"] = roles
        __props__.__dict__["user_id"] = user_id
        return UserRoles(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Output[Sequence[str]]:
        """
        Set of IDs of roles assigned to the user.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[str]:
        """
        ID of the user.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConnectionArgs', 'Connection']

@pulumi.input_type
class ConnectionArgs:
    def __init__(__self__, *,
                 strategy: pulumi.Input[str],
                 display_name: Optional[pulumi.Input[str]] = None,
                 is_domain_connection: Optional[pulumi.Input[bool]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input['ConnectionOptionsArgs']] = None,
                 realms: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 show_as_button: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Connection resource.
        :param pulumi.Input[str] strategy: Type of the connection, which indicates the identity provider.
        :param pulumi.Input[str] display_name: Name used in login screen.
        :param pulumi.Input[bool] is_domain_connection: Indicates whether the connection is domain level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: Metadata associated with the connection, in the form of a map of string values (max 255 chars).
        :param pulumi.Input[str] name: Name of the connection.
        :param pulumi.Input['ConnectionOptionsArgs'] options: Configuration settings for connection options.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] realms: Defines the realms for which the connection will be used (e.g., email domains). If not specified, the connection name is added as the realm.
        :param pulumi.Input[bool] show_as_button: Display connection as a button. Only available on enterprise connections.
        """
        pulumi.set(__self__, "strategy", strategy)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if is_domain_connection is not None:
            pulumi.set(__self__, "is_domain_connection", is_domain_connection)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if realms is not None:
            pulumi.set(__self__, "realms", realms)
        if show_as_button is not None:
            pulumi.set(__self__, "show_as_button", show_as_button)

    @property
    @pulumi.getter
    def strategy(self) -> pulumi.Input[str]:
        """
        Type of the connection, which indicates the identity provider.
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: pulumi.Input[str]):
        pulumi.set(self, "strategy", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name used in login screen.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="isDomainConnection")
    def is_domain_connection(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether the connection is domain level.
        """
        return pulumi.get(self, "is_domain_connection")

    @is_domain_connection.setter
    def is_domain_connection(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_domain_connection", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Metadata associated with the connection, in the form of a map of string values (max 255 chars).
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input['ConnectionOptionsArgs']]:
        """
        Configuration settings for connection options.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input['ConnectionOptionsArgs']]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter
    def realms(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Defines the realms for which the connection will be used (e.g., email domains). If not specified, the connection name is added as the realm.
        """
        return pulumi.get(self, "realms")

    @realms.setter
    def realms(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "realms", value)

    @property
    @pulumi.getter(name="showAsButton")
    def show_as_button(self) -> Optional[pulumi.Input[bool]]:
        """
        Display connection as a button. Only available on enterprise connections.
        """
        return pulumi.get(self, "show_as_button")

    @show_as_button.setter
    def show_as_button(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "show_as_button", value)


@pulumi.input_type
class _ConnectionState:
    def __init__(__self__, *,
                 display_name: Optional[pulumi.Input[str]] = None,
                 is_domain_connection: Optional[pulumi.Input[bool]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input['ConnectionOptionsArgs']] = None,
                 realms: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 show_as_button: Optional[pulumi.Input[bool]] = None,
                 strategy: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Connection resources.
        :param pulumi.Input[str] display_name: Name used in login screen.
        :param pulumi.Input[bool] is_domain_connection: Indicates whether the connection is domain level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: Metadata associated with the connection, in the form of a map of string values (max 255 chars).
        :param pulumi.Input[str] name: Name of the connection.
        :param pulumi.Input['ConnectionOptionsArgs'] options: Configuration settings for connection options.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] realms: Defines the realms for which the connection will be used (e.g., email domains). If not specified, the connection name is added as the realm.
        :param pulumi.Input[bool] show_as_button: Display connection as a button. Only available on enterprise connections.
        :param pulumi.Input[str] strategy: Type of the connection, which indicates the identity provider.
        """
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if is_domain_connection is not None:
            pulumi.set(__self__, "is_domain_connection", is_domain_connection)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if realms is not None:
            pulumi.set(__self__, "realms", realms)
        if show_as_button is not None:
            pulumi.set(__self__, "show_as_button", show_as_button)
        if strategy is not None:
            pulumi.set(__self__, "strategy", strategy)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name used in login screen.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="isDomainConnection")
    def is_domain_connection(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether the connection is domain level.
        """
        return pulumi.get(self, "is_domain_connection")

    @is_domain_connection.setter
    def is_domain_connection(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_domain_connection", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Metadata associated with the connection, in the form of a map of string values (max 255 chars).
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input['ConnectionOptionsArgs']]:
        """
        Configuration settings for connection options.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input['ConnectionOptionsArgs']]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter
    def realms(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Defines the realms for which the connection will be used (e.g., email domains). If not specified, the connection name is added as the realm.
        """
        return pulumi.get(self, "realms")

    @realms.setter
    def realms(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "realms", value)

    @property
    @pulumi.getter(name="showAsButton")
    def show_as_button(self) -> Optional[pulumi.Input[bool]]:
        """
        Display connection as a button. Only available on enterprise connections.
        """
        return pulumi.get(self, "show_as_button")

    @show_as_button.setter
    def show_as_button(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "show_as_button", value)

    @property
    @pulumi.getter
    def strategy(self) -> Optional[pulumi.Input[str]]:
        """
        Type of the connection, which indicates the identity provider.
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "strategy", value)


class Connection(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 is_domain_connection: Optional[pulumi.Input[bool]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input[pulumi.InputType['ConnectionOptionsArgs']]] = None,
                 realms: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 show_as_button: Optional[pulumi.Input[bool]] = None,
                 strategy: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        With Auth0, you can define sources of users, otherwise known as connections, which may include identity providers (such as Google or LinkedIn), databases, or passwordless authentication methods. This resource allows you to configure and manage connections to be used with your clients and users.

        > The Auth0 dashboard displays only one connection per social provider. Although the Auth0 Management API allows the
        creation of multiple connections per strategy, the additional connections may not be visible in the Auth0 dashboard.

        ## Example Usage

        ### Auth0 Connection

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        # This is an example of an Auth0 connection.
        my_connection = auth0.Connection("my_connection",
            name="Example-Connection",
            is_domain_connection=True,
            strategy="auth0",
            metadata={
                "key1": "foo",
                "key2": "bar",
            },
            options=auth0.ConnectionOptionsArgs(
                password_policy="excellent",
                brute_force_protection=True,
                enabled_database_customization=True,
                import_mode=False,
                requires_username=True,
                disable_signup=False,
                custom_scripts={
                    "get_user": \"\"\"        function getByEmail(email, callback) {
                  return callback(new Error("Whoops!"));
                }
        \"\"\",
                },
                configuration={
                    "foo": "bar",
                    "bar": "baz",
                },
                upstream_params=json.dumps({
                    "screen_name": {
                        "alias": "login_hint",
                    },
                }),
                password_histories=[auth0.ConnectionOptionsPasswordHistoryArgs(
                    enable=True,
                    size=3,
                )],
                password_no_personal_info=auth0.ConnectionOptionsPasswordNoPersonalInfoArgs(
                    enable=True,
                ),
                password_dictionary=auth0.ConnectionOptionsPasswordDictionaryArgs(
                    enable=True,
                    dictionaries=[
                        "password",
                        "admin",
                        "1234",
                    ],
                ),
                password_complexity_options=auth0.ConnectionOptionsPasswordComplexityOptionsArgs(
                    min_length=12,
                ),
                validation=auth0.ConnectionOptionsValidationArgs(
                    username=auth0.ConnectionOptionsValidationUsernameArgs(
                        min=10,
                        max=40,
                    ),
                ),
                mfa=auth0.ConnectionOptionsMfaArgs(
                    active=True,
                    return_enroll_settings=True,
                ),
            ))
        ```

        ### Google OAuth2 Connection

        > Your Auth0 account may be pre-configured with a `google-oauth2` connection.

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of a Google OAuth2 connection.
        google_oauth2 = auth0.Connection("google_oauth2",
            name="Google-OAuth2-Connection",
            strategy="google-oauth2",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                allowed_audiences=[
                    "example.com",
                    "api.example.com",
                ],
                scopes=[
                    "email",
                    "profile",
                    "gmail",
                    "youtube",
                ],
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### Google Apps

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        google_apps = auth0.Connection("google_apps",
            name="connection-google-apps",
            is_domain_connection=False,
            strategy="google-apps",
            show_as_button=False,
            options=auth0.ConnectionOptionsArgs(
                client_id="",
                client_secret="",
                domain="example.com",
                tenant_domain="example.com",
                domain_aliases=[
                    "example.com",
                    "api.example.com",
                ],
                api_enable_users=True,
                scopes=[
                    "ext_profile",
                    "ext_groups",
                ],
                icon_url="https://example.com/assets/logo.png",
                upstream_params=json.dumps({
                    "screen_name": {
                        "alias": "login_hint",
                    },
                }),
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### Facebook Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of a Facebook connection.
        facebook = auth0.Connection("facebook",
            name="Facebook-Connection",
            strategy="facebook",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                scopes=[
                    "public_profile",
                    "email",
                    "groups_access_member_info",
                    "user_birthday",
                ],
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### Apple Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an Apple connection.
        apple = auth0.Connection("apple",
            name="Apple-Connection",
            strategy="apple",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret=\"\"\"-----BEGIN PRIVATE KEY-----
        MIHBAgEAMA0GCSqGSIb3DQEBAQUABIGsMIGpAgEAA
        -----END PRIVATE KEY-----\"\"\",
                team_id="<team-id>",
                key_id="<key-id>",
                scopes=[
                    "email",
                    "name",
                ],
                set_user_root_attributes="on_first_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### LinkedIn Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an LinkedIn connection.
        linkedin = auth0.Connection("linkedin",
            name="Linkedin-Connection",
            strategy="linkedin",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                strategy_version=2,
                scopes=[
                    "basic_profile",
                    "profile",
                    "email",
                ],
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### GitHub Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an GitHub connection.
        github = auth0.Connection("github",
            name="GitHub-Connection",
            strategy="github",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                scopes=[
                    "email",
                    "profile",
                    "public_repo",
                    "repo",
                ],
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### SalesForce Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an SalesForce connection.
        salesforce = auth0.Connection("salesforce",
            name="Salesforce-Connection",
            strategy="salesforce",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                community_base_url="https://salesforce.example.com",
                scopes=[
                    "openid",
                    "email",
                ],
                set_user_root_attributes="on_first_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### OAuth2 Connection

        Also applies to following connection strategies: `dropbox`, `bitbucket`, `paypal`, `twitter`, `amazon`, `yahoo`, `box`, `wordpress`, `shopify`, `custom`

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an OAuth2 connection.
        oauth2 = auth0.Connection("oauth2",
            name="OAuth2-Connection",
            strategy="oauth2",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                scopes=[
                    "basic_profile",
                    "profile",
                    "email",
                ],
                token_endpoint="https://auth.example.com/oauth2/token",
                authorization_endpoint="https://auth.example.com/oauth2/authorize",
                pkce_enabled=True,
                icon_url="https://auth.example.com/assets/logo.png",
                scripts={
                    "fetchUserProfile": \"\"\"        function fetchUserProfile(accessToken, context, callback) {
                  return callback(new Error("Whoops!"));
                }
        \"\"\",
                },
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### Active Directory (AD)

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        ad = auth0.Connection("ad",
            name="connection-active-directory",
            display_name="Active Directory Connection",
            strategy="ad",
            show_as_button=True,
            options=auth0.ConnectionOptionsArgs(
                disable_self_service_change_password=True,
                brute_force_protection=True,
                tenant_domain="example.com",
                icon_url="https://example.com/assets/logo.png",
                domain_aliases=[
                    "example.com",
                    "api.example.com",
                ],
                ips=[
                    "192.168.1.1",
                    "192.168.1.2",
                ],
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
                upstream_params=json.dumps({
                    "screen_name": {
                        "alias": "login_hint",
                    },
                }),
                use_cert_auth=False,
                use_kerberos=False,
                disable_cache=False,
            ))
        ```

        ### Azure AD Connection

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        azure_ad = auth0.Connection("azure_ad",
            name="connection-azure-ad",
            strategy="waad",
            show_as_button=True,
            options=auth0.ConnectionOptionsArgs(
                identity_api="azure-active-directory-v1.0",
                client_id="123456",
                client_secret="123456",
                app_id="app-id-123",
                tenant_domain="example.onmicrosoft.com",
                domain="example.onmicrosoft.com",
                domain_aliases=[
                    "example.com",
                    "api.example.com",
                ],
                icon_url="https://example.onmicrosoft.com/assets/logo.png",
                use_wsfed=False,
                waad_protocol="openid-connect",
                waad_common_endpoint=False,
                max_groups_to_retrieve="250",
                api_enable_users=True,
                scopes=[
                    "basic_profile",
                    "ext_groups",
                    "ext_profile",
                ],
                set_user_root_attributes="on_each_login",
                should_trust_email_verified_connection="never_set_emails_as_verified",
                upstream_params=json.dumps({
                    "screen_name": {
                        "alias": "login_hint",
                    },
                }),
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### Email Connection

        > To be able to see this in the management dashboard as well, the name of the connection must be set to "email".

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an Email connection.
        passwordless_email = auth0.Connection("passwordless_email",
            strategy="email",
            name="email",
            options=auth0.ConnectionOptionsArgs(
                name="email",
                from_="{{ application.name }} <root@auth0.com>",
                subject="Welcome to {{ application.name }}",
                syntax="liquid",
                template="<html>This is the body of the email</html>",
                disable_signup=False,
                brute_force_protection=True,
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[],
                auth_params={
                    "scope": "openid email profile offline_access",
                    "response_type": "code",
                },
                totp=auth0.ConnectionOptionsTotpArgs(
                    time_step=300,
                    length=6,
                ),
            ))
        ```

        ### SAML Connection

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        # This is an example of a SAML connection.
        samlp = auth0.Connection("samlp",
            name="SAML-Connection",
            strategy="samlp",
            options=auth0.ConnectionOptionsArgs(
                debug=False,
                signing_cert="<signing-certificate>",
                sign_in_endpoint="https://saml.provider/sign_in",
                sign_out_endpoint="https://saml.provider/sign_out",
                disable_sign_out=True,
                tenant_domain="example.com",
                domain_aliases=[
                    "example.com",
                    "alias.example.com",
                ],
                protocol_binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
                request_template=\"\"\"<samlp:AuthnRequest xmlns:samlp="urn:oasis:names:tc:SAML:2.0:protocol"
        @@AssertServiceURLAndDestination@@
            ID="@@ID@@"
            IssueInstant="@@IssueInstant@@"
            ProtocolBinding="@@ProtocolBinding@@" Version="2.0">
            <saml:Issuer xmlns:saml="urn:oasis:names:tc:SAML:2.0:assertion">@@Issuer@@</saml:Issuer>
        </samlp:AuthnRequest>\"\"\",
                user_id_attribute="https://saml.provider/imi/ns/identity-200810",
                signature_algorithm="rsa-sha256",
                digest_algorithm="sha256",
                icon_url="https://saml.provider/assets/logo.png",
                entity_id="<entity_id>",
                metadata_xml=\"\"\"    <?xml version="1.0"?>
            <md:EntityDescriptor xmlns:md="urn:oasis:names:tc:SAML:2.0:metadata" xmlns:ds="http://www.w3.org/2000/09/xmldsig#" entityID="https://example.com">
              <md:IDPSSODescriptor protocolSupportEnumeration="urn:oasis:names:tc:SAML:2.0:protocol">
                <md:SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect" Location="https://saml.provider/sign_out"/>
                <md:SingleSignOnService Binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect" Location="https://saml.provider/sign_in"/>
              </md:IDPSSODescriptor>
            </md:EntityDescriptor>
        \"\"\",
                metadata_url="https://saml.provider/imi/ns/FederationMetadata.xml",
                fields_map=json.dumps({
                    "name": [
                        "name",
                        "nameidentifier",
                    ],
                    "email": [
                        "emailaddress",
                        "nameidentifier",
                    ],
                    "family_name": "surname",
                }),
                signing_key=auth0.ConnectionOptionsSigningKeyArgs(
                    key=\"\"\"-----BEGIN PRIVATE KEY-----
        ...{your private key here}...
        -----END PRIVATE KEY-----\"\"\",
                    cert=\"\"\"-----BEGIN CERTIFICATE-----
        ...{your public key cert here}...
        -----END CERTIFICATE-----\"\"\",
                ),
                decryption_key=auth0.ConnectionOptionsDecryptionKeyArgs(
                    key=\"\"\"-----BEGIN PRIVATE KEY-----
        ...{your private key here}...
        -----END PRIVATE KEY-----\"\"\",
                    cert=\"\"\"-----BEGIN CERTIFICATE-----
        ...{your public key cert here}...
        -----END CERTIFICATE-----\"\"\",
                ),
                idp_initiated=auth0.ConnectionOptionsIdpInitiatedArgs(
                    client_id="client_id",
                    client_protocol="samlp",
                    client_authorize_query="type=code&timeout=30",
                ),
            ))
        ```

        ### WindowsLive Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of a WindowsLive connection.
        windowslive = auth0.Connection("windowslive",
            name="Windowslive-Connection",
            strategy="windowslive",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                strategy_version=2,
                scopes=[
                    "signin",
                    "graph_user",
                ],
                set_user_root_attributes="on_first_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### OIDC Connection

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        # This is an example of an OIDC connection.
        oidc = auth0.Connection("oidc",
            name="oidc-connection",
            display_name="OIDC Connection",
            strategy="oidc",
            show_as_button=False,
            options=auth0.ConnectionOptionsArgs(
                client_id="1234567",
                client_secret="1234567",
                domain_aliases=["example.com"],
                tenant_domain="",
                icon_url="https://example.com/assets/logo.png",
                type="back_channel",
                issuer="https://www.paypalobjects.com",
                jwks_uri="https://api.paypal.com/v1/oauth2/certs",
                discovery_url="https://www.paypalobjects.com/.well-known/openid-configuration",
                token_endpoint="https://api.paypal.com/v1/oauth2/token",
                userinfo_endpoint="https://api.paypal.com/v1/oauth2/token/userinfo",
                authorization_endpoint="https://www.paypal.com/signin/authorize",
                scopes=[
                    "openid",
                    "email",
                ],
                set_user_root_attributes="on_first_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
                connection_settings=auth0.ConnectionOptionsConnectionSettingsArgs(
                    pkce="auto",
                ),
                attribute_map=auth0.ConnectionOptionsAttributeMapArgs(
                    mapping_mode="use_map",
                    userinfo_scope="openid email profile groups",
                    attributes=json.dumps({
                        "name": "${context.tokenset.name}",
                        "email": "${context.tokenset.email}",
                        "email_verified": "${context.tokenset.email_verified}",
                        "nickname": "${context.tokenset.nickname}",
                        "picture": "${context.tokenset.picture}",
                        "given_name": "${context.tokenset.given_name}",
                        "family_name": "${context.tokenset.family_name}",
                    }),
                ),
            ))
        ```

        ### Okta Connection

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        # This is an example of an Okta Workforce connection.
        okta = auth0.Connection("okta",
            name="okta-connection",
            display_name="Okta Workforce Connection",
            strategy="okta",
            show_as_button=False,
            options=auth0.ConnectionOptionsArgs(
                client_id="1234567",
                client_secret="1234567",
                domain="example.okta.com",
                domain_aliases=["example.com"],
                issuer="https://example.okta.com",
                jwks_uri="https://example.okta.com/oauth2/v1/keys",
                token_endpoint="https://example.okta.com/oauth2/v1/token",
                userinfo_endpoint="https://example.okta.com/oauth2/v1/userinfo",
                authorization_endpoint="https://example.okta.com/oauth2/v1/authorize",
                scopes=[
                    "openid",
                    "email",
                ],
                set_user_root_attributes="on_first_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
                upstream_params=json.dumps({
                    "screen_name": {
                        "alias": "login_hint",
                    },
                }),
                connection_settings=auth0.ConnectionOptionsConnectionSettingsArgs(
                    pkce="auto",
                ),
                attribute_map=auth0.ConnectionOptionsAttributeMapArgs(
                    mapping_mode="basic_profile",
                    userinfo_scope="openid email profile groups",
                    attributes=json.dumps({
                        "name": "${context.tokenset.name}",
                        "email": "${context.tokenset.email}",
                        "email_verified": "${context.tokenset.email_verified}",
                        "nickname": "${context.tokenset.nickname}",
                        "picture": "${context.tokenset.picture}",
                        "given_name": "${context.tokenset.given_name}",
                        "family_name": "${context.tokenset.family_name}",
                    }),
                ),
            ))
        ```

        ## Import

        This resource can be imported by specifying the connection ID.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/connection:Connection google "con_a17f21fdb24d48a0"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] display_name: Name used in login screen.
        :param pulumi.Input[bool] is_domain_connection: Indicates whether the connection is domain level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: Metadata associated with the connection, in the form of a map of string values (max 255 chars).
        :param pulumi.Input[str] name: Name of the connection.
        :param pulumi.Input[pulumi.InputType['ConnectionOptionsArgs']] options: Configuration settings for connection options.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] realms: Defines the realms for which the connection will be used (e.g., email domains). If not specified, the connection name is added as the realm.
        :param pulumi.Input[bool] show_as_button: Display connection as a button. Only available on enterprise connections.
        :param pulumi.Input[str] strategy: Type of the connection, which indicates the identity provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConnectionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        With Auth0, you can define sources of users, otherwise known as connections, which may include identity providers (such as Google or LinkedIn), databases, or passwordless authentication methods. This resource allows you to configure and manage connections to be used with your clients and users.

        > The Auth0 dashboard displays only one connection per social provider. Although the Auth0 Management API allows the
        creation of multiple connections per strategy, the additional connections may not be visible in the Auth0 dashboard.

        ## Example Usage

        ### Auth0 Connection

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        # This is an example of an Auth0 connection.
        my_connection = auth0.Connection("my_connection",
            name="Example-Connection",
            is_domain_connection=True,
            strategy="auth0",
            metadata={
                "key1": "foo",
                "key2": "bar",
            },
            options=auth0.ConnectionOptionsArgs(
                password_policy="excellent",
                brute_force_protection=True,
                enabled_database_customization=True,
                import_mode=False,
                requires_username=True,
                disable_signup=False,
                custom_scripts={
                    "get_user": \"\"\"        function getByEmail(email, callback) {
                  return callback(new Error("Whoops!"));
                }
        \"\"\",
                },
                configuration={
                    "foo": "bar",
                    "bar": "baz",
                },
                upstream_params=json.dumps({
                    "screen_name": {
                        "alias": "login_hint",
                    },
                }),
                password_histories=[auth0.ConnectionOptionsPasswordHistoryArgs(
                    enable=True,
                    size=3,
                )],
                password_no_personal_info=auth0.ConnectionOptionsPasswordNoPersonalInfoArgs(
                    enable=True,
                ),
                password_dictionary=auth0.ConnectionOptionsPasswordDictionaryArgs(
                    enable=True,
                    dictionaries=[
                        "password",
                        "admin",
                        "1234",
                    ],
                ),
                password_complexity_options=auth0.ConnectionOptionsPasswordComplexityOptionsArgs(
                    min_length=12,
                ),
                validation=auth0.ConnectionOptionsValidationArgs(
                    username=auth0.ConnectionOptionsValidationUsernameArgs(
                        min=10,
                        max=40,
                    ),
                ),
                mfa=auth0.ConnectionOptionsMfaArgs(
                    active=True,
                    return_enroll_settings=True,
                ),
            ))
        ```

        ### Google OAuth2 Connection

        > Your Auth0 account may be pre-configured with a `google-oauth2` connection.

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of a Google OAuth2 connection.
        google_oauth2 = auth0.Connection("google_oauth2",
            name="Google-OAuth2-Connection",
            strategy="google-oauth2",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                allowed_audiences=[
                    "example.com",
                    "api.example.com",
                ],
                scopes=[
                    "email",
                    "profile",
                    "gmail",
                    "youtube",
                ],
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### Google Apps

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        google_apps = auth0.Connection("google_apps",
            name="connection-google-apps",
            is_domain_connection=False,
            strategy="google-apps",
            show_as_button=False,
            options=auth0.ConnectionOptionsArgs(
                client_id="",
                client_secret="",
                domain="example.com",
                tenant_domain="example.com",
                domain_aliases=[
                    "example.com",
                    "api.example.com",
                ],
                api_enable_users=True,
                scopes=[
                    "ext_profile",
                    "ext_groups",
                ],
                icon_url="https://example.com/assets/logo.png",
                upstream_params=json.dumps({
                    "screen_name": {
                        "alias": "login_hint",
                    },
                }),
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### Facebook Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of a Facebook connection.
        facebook = auth0.Connection("facebook",
            name="Facebook-Connection",
            strategy="facebook",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                scopes=[
                    "public_profile",
                    "email",
                    "groups_access_member_info",
                    "user_birthday",
                ],
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### Apple Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an Apple connection.
        apple = auth0.Connection("apple",
            name="Apple-Connection",
            strategy="apple",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret=\"\"\"-----BEGIN PRIVATE KEY-----
        MIHBAgEAMA0GCSqGSIb3DQEBAQUABIGsMIGpAgEAA
        -----END PRIVATE KEY-----\"\"\",
                team_id="<team-id>",
                key_id="<key-id>",
                scopes=[
                    "email",
                    "name",
                ],
                set_user_root_attributes="on_first_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### LinkedIn Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an LinkedIn connection.
        linkedin = auth0.Connection("linkedin",
            name="Linkedin-Connection",
            strategy="linkedin",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                strategy_version=2,
                scopes=[
                    "basic_profile",
                    "profile",
                    "email",
                ],
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### GitHub Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an GitHub connection.
        github = auth0.Connection("github",
            name="GitHub-Connection",
            strategy="github",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                scopes=[
                    "email",
                    "profile",
                    "public_repo",
                    "repo",
                ],
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### SalesForce Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an SalesForce connection.
        salesforce = auth0.Connection("salesforce",
            name="Salesforce-Connection",
            strategy="salesforce",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                community_base_url="https://salesforce.example.com",
                scopes=[
                    "openid",
                    "email",
                ],
                set_user_root_attributes="on_first_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### OAuth2 Connection

        Also applies to following connection strategies: `dropbox`, `bitbucket`, `paypal`, `twitter`, `amazon`, `yahoo`, `box`, `wordpress`, `shopify`, `custom`

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an OAuth2 connection.
        oauth2 = auth0.Connection("oauth2",
            name="OAuth2-Connection",
            strategy="oauth2",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                scopes=[
                    "basic_profile",
                    "profile",
                    "email",
                ],
                token_endpoint="https://auth.example.com/oauth2/token",
                authorization_endpoint="https://auth.example.com/oauth2/authorize",
                pkce_enabled=True,
                icon_url="https://auth.example.com/assets/logo.png",
                scripts={
                    "fetchUserProfile": \"\"\"        function fetchUserProfile(accessToken, context, callback) {
                  return callback(new Error("Whoops!"));
                }
        \"\"\",
                },
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### Active Directory (AD)

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        ad = auth0.Connection("ad",
            name="connection-active-directory",
            display_name="Active Directory Connection",
            strategy="ad",
            show_as_button=True,
            options=auth0.ConnectionOptionsArgs(
                disable_self_service_change_password=True,
                brute_force_protection=True,
                tenant_domain="example.com",
                icon_url="https://example.com/assets/logo.png",
                domain_aliases=[
                    "example.com",
                    "api.example.com",
                ],
                ips=[
                    "192.168.1.1",
                    "192.168.1.2",
                ],
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
                upstream_params=json.dumps({
                    "screen_name": {
                        "alias": "login_hint",
                    },
                }),
                use_cert_auth=False,
                use_kerberos=False,
                disable_cache=False,
            ))
        ```

        ### Azure AD Connection

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        azure_ad = auth0.Connection("azure_ad",
            name="connection-azure-ad",
            strategy="waad",
            show_as_button=True,
            options=auth0.ConnectionOptionsArgs(
                identity_api="azure-active-directory-v1.0",
                client_id="123456",
                client_secret="123456",
                app_id="app-id-123",
                tenant_domain="example.onmicrosoft.com",
                domain="example.onmicrosoft.com",
                domain_aliases=[
                    "example.com",
                    "api.example.com",
                ],
                icon_url="https://example.onmicrosoft.com/assets/logo.png",
                use_wsfed=False,
                waad_protocol="openid-connect",
                waad_common_endpoint=False,
                max_groups_to_retrieve="250",
                api_enable_users=True,
                scopes=[
                    "basic_profile",
                    "ext_groups",
                    "ext_profile",
                ],
                set_user_root_attributes="on_each_login",
                should_trust_email_verified_connection="never_set_emails_as_verified",
                upstream_params=json.dumps({
                    "screen_name": {
                        "alias": "login_hint",
                    },
                }),
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### Email Connection

        > To be able to see this in the management dashboard as well, the name of the connection must be set to "email".

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of an Email connection.
        passwordless_email = auth0.Connection("passwordless_email",
            strategy="email",
            name="email",
            options=auth0.ConnectionOptionsArgs(
                name="email",
                from_="{{ application.name }} <root@auth0.com>",
                subject="Welcome to {{ application.name }}",
                syntax="liquid",
                template="<html>This is the body of the email</html>",
                disable_signup=False,
                brute_force_protection=True,
                set_user_root_attributes="on_each_login",
                non_persistent_attrs=[],
                auth_params={
                    "scope": "openid email profile offline_access",
                    "response_type": "code",
                },
                totp=auth0.ConnectionOptionsTotpArgs(
                    time_step=300,
                    length=6,
                ),
            ))
        ```

        ### SAML Connection

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        # This is an example of a SAML connection.
        samlp = auth0.Connection("samlp",
            name="SAML-Connection",
            strategy="samlp",
            options=auth0.ConnectionOptionsArgs(
                debug=False,
                signing_cert="<signing-certificate>",
                sign_in_endpoint="https://saml.provider/sign_in",
                sign_out_endpoint="https://saml.provider/sign_out",
                disable_sign_out=True,
                tenant_domain="example.com",
                domain_aliases=[
                    "example.com",
                    "alias.example.com",
                ],
                protocol_binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
                request_template=\"\"\"<samlp:AuthnRequest xmlns:samlp="urn:oasis:names:tc:SAML:2.0:protocol"
        @@AssertServiceURLAndDestination@@
            ID="@@ID@@"
            IssueInstant="@@IssueInstant@@"
            ProtocolBinding="@@ProtocolBinding@@" Version="2.0">
            <saml:Issuer xmlns:saml="urn:oasis:names:tc:SAML:2.0:assertion">@@Issuer@@</saml:Issuer>
        </samlp:AuthnRequest>\"\"\",
                user_id_attribute="https://saml.provider/imi/ns/identity-200810",
                signature_algorithm="rsa-sha256",
                digest_algorithm="sha256",
                icon_url="https://saml.provider/assets/logo.png",
                entity_id="<entity_id>",
                metadata_xml=\"\"\"    <?xml version="1.0"?>
            <md:EntityDescriptor xmlns:md="urn:oasis:names:tc:SAML:2.0:metadata" xmlns:ds="http://www.w3.org/2000/09/xmldsig#" entityID="https://example.com">
              <md:IDPSSODescriptor protocolSupportEnumeration="urn:oasis:names:tc:SAML:2.0:protocol">
                <md:SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect" Location="https://saml.provider/sign_out"/>
                <md:SingleSignOnService Binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect" Location="https://saml.provider/sign_in"/>
              </md:IDPSSODescriptor>
            </md:EntityDescriptor>
        \"\"\",
                metadata_url="https://saml.provider/imi/ns/FederationMetadata.xml",
                fields_map=json.dumps({
                    "name": [
                        "name",
                        "nameidentifier",
                    ],
                    "email": [
                        "emailaddress",
                        "nameidentifier",
                    ],
                    "family_name": "surname",
                }),
                signing_key=auth0.ConnectionOptionsSigningKeyArgs(
                    key=\"\"\"-----BEGIN PRIVATE KEY-----
        ...{your private key here}...
        -----END PRIVATE KEY-----\"\"\",
                    cert=\"\"\"-----BEGIN CERTIFICATE-----
        ...{your public key cert here}...
        -----END CERTIFICATE-----\"\"\",
                ),
                decryption_key=auth0.ConnectionOptionsDecryptionKeyArgs(
                    key=\"\"\"-----BEGIN PRIVATE KEY-----
        ...{your private key here}...
        -----END PRIVATE KEY-----\"\"\",
                    cert=\"\"\"-----BEGIN CERTIFICATE-----
        ...{your public key cert here}...
        -----END CERTIFICATE-----\"\"\",
                ),
                idp_initiated=auth0.ConnectionOptionsIdpInitiatedArgs(
                    client_id="client_id",
                    client_protocol="samlp",
                    client_authorize_query="type=code&timeout=30",
                ),
            ))
        ```

        ### WindowsLive Connection

        ```python
        import pulumi
        import pulumi_auth0 as auth0

        # This is an example of a WindowsLive connection.
        windowslive = auth0.Connection("windowslive",
            name="Windowslive-Connection",
            strategy="windowslive",
            options=auth0.ConnectionOptionsArgs(
                client_id="<client-id>",
                client_secret="<client-secret>",
                strategy_version=2,
                scopes=[
                    "signin",
                    "graph_user",
                ],
                set_user_root_attributes="on_first_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
            ))
        ```

        ### OIDC Connection

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        # This is an example of an OIDC connection.
        oidc = auth0.Connection("oidc",
            name="oidc-connection",
            display_name="OIDC Connection",
            strategy="oidc",
            show_as_button=False,
            options=auth0.ConnectionOptionsArgs(
                client_id="1234567",
                client_secret="1234567",
                domain_aliases=["example.com"],
                tenant_domain="",
                icon_url="https://example.com/assets/logo.png",
                type="back_channel",
                issuer="https://www.paypalobjects.com",
                jwks_uri="https://api.paypal.com/v1/oauth2/certs",
                discovery_url="https://www.paypalobjects.com/.well-known/openid-configuration",
                token_endpoint="https://api.paypal.com/v1/oauth2/token",
                userinfo_endpoint="https://api.paypal.com/v1/oauth2/token/userinfo",
                authorization_endpoint="https://www.paypal.com/signin/authorize",
                scopes=[
                    "openid",
                    "email",
                ],
                set_user_root_attributes="on_first_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
                connection_settings=auth0.ConnectionOptionsConnectionSettingsArgs(
                    pkce="auto",
                ),
                attribute_map=auth0.ConnectionOptionsAttributeMapArgs(
                    mapping_mode="use_map",
                    userinfo_scope="openid email profile groups",
                    attributes=json.dumps({
                        "name": "${context.tokenset.name}",
                        "email": "${context.tokenset.email}",
                        "email_verified": "${context.tokenset.email_verified}",
                        "nickname": "${context.tokenset.nickname}",
                        "picture": "${context.tokenset.picture}",
                        "given_name": "${context.tokenset.given_name}",
                        "family_name": "${context.tokenset.family_name}",
                    }),
                ),
            ))
        ```

        ### Okta Connection

        ```python
        import pulumi
        import json
        import pulumi_auth0 as auth0

        # This is an example of an Okta Workforce connection.
        okta = auth0.Connection("okta",
            name="okta-connection",
            display_name="Okta Workforce Connection",
            strategy="okta",
            show_as_button=False,
            options=auth0.ConnectionOptionsArgs(
                client_id="1234567",
                client_secret="1234567",
                domain="example.okta.com",
                domain_aliases=["example.com"],
                issuer="https://example.okta.com",
                jwks_uri="https://example.okta.com/oauth2/v1/keys",
                token_endpoint="https://example.okta.com/oauth2/v1/token",
                userinfo_endpoint="https://example.okta.com/oauth2/v1/userinfo",
                authorization_endpoint="https://example.okta.com/oauth2/v1/authorize",
                scopes=[
                    "openid",
                    "email",
                ],
                set_user_root_attributes="on_first_login",
                non_persistent_attrs=[
                    "ethnicity",
                    "gender",
                ],
                upstream_params=json.dumps({
                    "screen_name": {
                        "alias": "login_hint",
                    },
                }),
                connection_settings=auth0.ConnectionOptionsConnectionSettingsArgs(
                    pkce="auto",
                ),
                attribute_map=auth0.ConnectionOptionsAttributeMapArgs(
                    mapping_mode="basic_profile",
                    userinfo_scope="openid email profile groups",
                    attributes=json.dumps({
                        "name": "${context.tokenset.name}",
                        "email": "${context.tokenset.email}",
                        "email_verified": "${context.tokenset.email_verified}",
                        "nickname": "${context.tokenset.nickname}",
                        "picture": "${context.tokenset.picture}",
                        "given_name": "${context.tokenset.given_name}",
                        "family_name": "${context.tokenset.family_name}",
                    }),
                ),
            ))
        ```

        ## Import

        This resource can be imported by specifying the connection ID.

        # 

        Example:

        ```sh
        $ pulumi import auth0:index/connection:Connection google "con_a17f21fdb24d48a0"
        ```

        :param str resource_name: The name of the resource.
        :param ConnectionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 is_domain_connection: Optional[pulumi.Input[bool]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input[pulumi.InputType['ConnectionOptionsArgs']]] = None,
                 realms: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 show_as_button: Optional[pulumi.Input[bool]] = None,
                 strategy: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectionArgs.__new__(ConnectionArgs)

            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["is_domain_connection"] = is_domain_connection
            __props__.__dict__["metadata"] = metadata
            __props__.__dict__["name"] = name
            __props__.__dict__["options"] = options
            __props__.__dict__["realms"] = realms
            __props__.__dict__["show_as_button"] = show_as_button
            if strategy is None and not opts.urn:
                raise TypeError("Missing required property 'strategy'")
            __props__.__dict__["strategy"] = strategy
        super(Connection, __self__).__init__(
            'auth0:index/connection:Connection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            is_domain_connection: Optional[pulumi.Input[bool]] = None,
            metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            options: Optional[pulumi.Input[pulumi.InputType['ConnectionOptionsArgs']]] = None,
            realms: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            show_as_button: Optional[pulumi.Input[bool]] = None,
            strategy: Optional[pulumi.Input[str]] = None) -> 'Connection':
        """
        Get an existing Connection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] display_name: Name used in login screen.
        :param pulumi.Input[bool] is_domain_connection: Indicates whether the connection is domain level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: Metadata associated with the connection, in the form of a map of string values (max 255 chars).
        :param pulumi.Input[str] name: Name of the connection.
        :param pulumi.Input[pulumi.InputType['ConnectionOptionsArgs']] options: Configuration settings for connection options.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] realms: Defines the realms for which the connection will be used (e.g., email domains). If not specified, the connection name is added as the realm.
        :param pulumi.Input[bool] show_as_button: Display connection as a button. Only available on enterprise connections.
        :param pulumi.Input[str] strategy: Type of the connection, which indicates the identity provider.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectionState.__new__(_ConnectionState)

        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["is_domain_connection"] = is_domain_connection
        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["name"] = name
        __props__.__dict__["options"] = options
        __props__.__dict__["realms"] = realms
        __props__.__dict__["show_as_button"] = show_as_button
        __props__.__dict__["strategy"] = strategy
        return Connection(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[str]]:
        """
        Name used in login screen.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="isDomainConnection")
    def is_domain_connection(self) -> pulumi.Output[bool]:
        """
        Indicates whether the connection is domain level.
        """
        return pulumi.get(self, "is_domain_connection")

    @property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Metadata associated with the connection, in the form of a map of string values (max 255 chars).
        """
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the connection.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def options(self) -> pulumi.Output['outputs.ConnectionOptions']:
        """
        Configuration settings for connection options.
        """
        return pulumi.get(self, "options")

    @property
    @pulumi.getter
    def realms(self) -> pulumi.Output[Sequence[str]]:
        """
        Defines the realms for which the connection will be used (e.g., email domains). If not specified, the connection name is added as the realm.
        """
        return pulumi.get(self, "realms")

    @property
    @pulumi.getter(name="showAsButton")
    def show_as_button(self) -> pulumi.Output[Optional[bool]]:
        """
        Display connection as a button. Only available on enterprise connections.
        """
        return pulumi.get(self, "show_as_button")

    @property
    @pulumi.getter
    def strategy(self) -> pulumi.Output[str]:
        """
        Type of the connection, which indicates the identity provider.
        """
        return pulumi.get(self, "strategy")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetClientResult',
    'AwaitableGetClientResult',
    'get_client',
    'get_client_output',
]

@pulumi.output_type
class GetClientResult:
    """
    A collection of values returned by getClient.
    """
    def __init__(__self__, addons=None, allowed_clients=None, allowed_logout_urls=None, allowed_origins=None, app_type=None, callbacks=None, client_aliases=None, client_id=None, client_metadata=None, client_secret=None, cross_origin_auth=None, cross_origin_loc=None, custom_login_page=None, custom_login_page_on=None, description=None, encryption_key=None, form_template=None, grant_types=None, id=None, initiate_login_uri=None, is_first_party=None, is_token_endpoint_ip_header_trusted=None, jwt_configurations=None, logo_uri=None, mobiles=None, name=None, native_social_logins=None, oidc_backchannel_logout_urls=None, oidc_conformant=None, organization_require_behavior=None, organization_usage=None, refresh_tokens=None, require_pushed_authorization_requests=None, signing_keys=None, sso=None, sso_disabled=None, token_endpoint_auth_method=None, web_origins=None):
        if addons and not isinstance(addons, list):
            raise TypeError("Expected argument 'addons' to be a list")
        pulumi.set(__self__, "addons", addons)
        if allowed_clients and not isinstance(allowed_clients, list):
            raise TypeError("Expected argument 'allowed_clients' to be a list")
        pulumi.set(__self__, "allowed_clients", allowed_clients)
        if allowed_logout_urls and not isinstance(allowed_logout_urls, list):
            raise TypeError("Expected argument 'allowed_logout_urls' to be a list")
        pulumi.set(__self__, "allowed_logout_urls", allowed_logout_urls)
        if allowed_origins and not isinstance(allowed_origins, list):
            raise TypeError("Expected argument 'allowed_origins' to be a list")
        pulumi.set(__self__, "allowed_origins", allowed_origins)
        if app_type and not isinstance(app_type, str):
            raise TypeError("Expected argument 'app_type' to be a str")
        pulumi.set(__self__, "app_type", app_type)
        if callbacks and not isinstance(callbacks, list):
            raise TypeError("Expected argument 'callbacks' to be a list")
        pulumi.set(__self__, "callbacks", callbacks)
        if client_aliases and not isinstance(client_aliases, list):
            raise TypeError("Expected argument 'client_aliases' to be a list")
        pulumi.set(__self__, "client_aliases", client_aliases)
        if client_id and not isinstance(client_id, str):
            raise TypeError("Expected argument 'client_id' to be a str")
        pulumi.set(__self__, "client_id", client_id)
        if client_metadata and not isinstance(client_metadata, dict):
            raise TypeError("Expected argument 'client_metadata' to be a dict")
        pulumi.set(__self__, "client_metadata", client_metadata)
        if client_secret and not isinstance(client_secret, str):
            raise TypeError("Expected argument 'client_secret' to be a str")
        pulumi.set(__self__, "client_secret", client_secret)
        if cross_origin_auth and not isinstance(cross_origin_auth, bool):
            raise TypeError("Expected argument 'cross_origin_auth' to be a bool")
        pulumi.set(__self__, "cross_origin_auth", cross_origin_auth)
        if cross_origin_loc and not isinstance(cross_origin_loc, str):
            raise TypeError("Expected argument 'cross_origin_loc' to be a str")
        pulumi.set(__self__, "cross_origin_loc", cross_origin_loc)
        if custom_login_page and not isinstance(custom_login_page, str):
            raise TypeError("Expected argument 'custom_login_page' to be a str")
        pulumi.set(__self__, "custom_login_page", custom_login_page)
        if custom_login_page_on and not isinstance(custom_login_page_on, bool):
            raise TypeError("Expected argument 'custom_login_page_on' to be a bool")
        pulumi.set(__self__, "custom_login_page_on", custom_login_page_on)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if encryption_key and not isinstance(encryption_key, dict):
            raise TypeError("Expected argument 'encryption_key' to be a dict")
        pulumi.set(__self__, "encryption_key", encryption_key)
        if form_template and not isinstance(form_template, str):
            raise TypeError("Expected argument 'form_template' to be a str")
        pulumi.set(__self__, "form_template", form_template)
        if grant_types and not isinstance(grant_types, list):
            raise TypeError("Expected argument 'grant_types' to be a list")
        pulumi.set(__self__, "grant_types", grant_types)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if initiate_login_uri and not isinstance(initiate_login_uri, str):
            raise TypeError("Expected argument 'initiate_login_uri' to be a str")
        pulumi.set(__self__, "initiate_login_uri", initiate_login_uri)
        if is_first_party and not isinstance(is_first_party, bool):
            raise TypeError("Expected argument 'is_first_party' to be a bool")
        pulumi.set(__self__, "is_first_party", is_first_party)
        if is_token_endpoint_ip_header_trusted and not isinstance(is_token_endpoint_ip_header_trusted, bool):
            raise TypeError("Expected argument 'is_token_endpoint_ip_header_trusted' to be a bool")
        pulumi.set(__self__, "is_token_endpoint_ip_header_trusted", is_token_endpoint_ip_header_trusted)
        if jwt_configurations and not isinstance(jwt_configurations, list):
            raise TypeError("Expected argument 'jwt_configurations' to be a list")
        pulumi.set(__self__, "jwt_configurations", jwt_configurations)
        if logo_uri and not isinstance(logo_uri, str):
            raise TypeError("Expected argument 'logo_uri' to be a str")
        pulumi.set(__self__, "logo_uri", logo_uri)
        if mobiles and not isinstance(mobiles, list):
            raise TypeError("Expected argument 'mobiles' to be a list")
        pulumi.set(__self__, "mobiles", mobiles)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if native_social_logins and not isinstance(native_social_logins, list):
            raise TypeError("Expected argument 'native_social_logins' to be a list")
        pulumi.set(__self__, "native_social_logins", native_social_logins)
        if oidc_backchannel_logout_urls and not isinstance(oidc_backchannel_logout_urls, list):
            raise TypeError("Expected argument 'oidc_backchannel_logout_urls' to be a list")
        pulumi.set(__self__, "oidc_backchannel_logout_urls", oidc_backchannel_logout_urls)
        if oidc_conformant and not isinstance(oidc_conformant, bool):
            raise TypeError("Expected argument 'oidc_conformant' to be a bool")
        pulumi.set(__self__, "oidc_conformant", oidc_conformant)
        if organization_require_behavior and not isinstance(organization_require_behavior, str):
            raise TypeError("Expected argument 'organization_require_behavior' to be a str")
        pulumi.set(__self__, "organization_require_behavior", organization_require_behavior)
        if organization_usage and not isinstance(organization_usage, str):
            raise TypeError("Expected argument 'organization_usage' to be a str")
        pulumi.set(__self__, "organization_usage", organization_usage)
        if refresh_tokens and not isinstance(refresh_tokens, list):
            raise TypeError("Expected argument 'refresh_tokens' to be a list")
        pulumi.set(__self__, "refresh_tokens", refresh_tokens)
        if require_pushed_authorization_requests and not isinstance(require_pushed_authorization_requests, bool):
            raise TypeError("Expected argument 'require_pushed_authorization_requests' to be a bool")
        pulumi.set(__self__, "require_pushed_authorization_requests", require_pushed_authorization_requests)
        if signing_keys and not isinstance(signing_keys, list):
            raise TypeError("Expected argument 'signing_keys' to be a list")
        pulumi.set(__self__, "signing_keys", signing_keys)
        if sso and not isinstance(sso, bool):
            raise TypeError("Expected argument 'sso' to be a bool")
        pulumi.set(__self__, "sso", sso)
        if sso_disabled and not isinstance(sso_disabled, bool):
            raise TypeError("Expected argument 'sso_disabled' to be a bool")
        pulumi.set(__self__, "sso_disabled", sso_disabled)
        if token_endpoint_auth_method and not isinstance(token_endpoint_auth_method, str):
            raise TypeError("Expected argument 'token_endpoint_auth_method' to be a str")
        pulumi.set(__self__, "token_endpoint_auth_method", token_endpoint_auth_method)
        if web_origins and not isinstance(web_origins, list):
            raise TypeError("Expected argument 'web_origins' to be a list")
        pulumi.set(__self__, "web_origins", web_origins)

    @property
    @pulumi.getter
    def addons(self) -> Sequence['outputs.GetClientAddonResult']:
        """
        Addons enabled for this client and their associated configurations.
        """
        return pulumi.get(self, "addons")

    @property
    @pulumi.getter(name="allowedClients")
    def allowed_clients(self) -> Sequence[str]:
        """
        List of applications ID's that will be allowed to make delegation request. By default, all applications will be allowed.
        """
        return pulumi.get(self, "allowed_clients")

    @property
    @pulumi.getter(name="allowedLogoutUrls")
    def allowed_logout_urls(self) -> Sequence[str]:
        """
        URLs that Auth0 may redirect to after logout.
        """
        return pulumi.get(self, "allowed_logout_urls")

    @property
    @pulumi.getter(name="allowedOrigins")
    def allowed_origins(self) -> Sequence[str]:
        """
        URLs that represent valid origins for cross-origin resource sharing. By default, all your callback URLs will be allowed.
        """
        return pulumi.get(self, "allowed_origins")

    @property
    @pulumi.getter(name="appType")
    def app_type(self) -> str:
        """
        Type of application the client represents. Possible values are: `native`, `spa`, `regular_web`, `non_interactive`, `sso_integration`. Specific SSO integrations types accepted as well are: `rms`, `box`, `cloudbees`, `concur`, `dropbox`, `mscrm`, `echosign`, `egnyte`, `newrelic`, `office365`, `salesforce`, `sentry`, `sharepoint`, `slack`, `springcm`, `zendesk`, `zoom`.
        """
        return pulumi.get(self, "app_type")

    @property
    @pulumi.getter
    def callbacks(self) -> Sequence[str]:
        """
        URLs that Auth0 may call back to after a user authenticates for the client. Make sure to specify the protocol (https://) otherwise the callback may fail in some cases. With the exception of custom URI schemes for native clients, all callbacks should use protocol https://.
        """
        return pulumi.get(self, "callbacks")

    @property
    @pulumi.getter(name="clientAliases")
    def client_aliases(self) -> Sequence[str]:
        """
        List of audiences/realms for SAML protocol. Used by the wsfed addon.
        """
        return pulumi.get(self, "client_aliases")

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[str]:
        """
        The ID of the client. If not provided, `name` must be set.
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientMetadata")
    def client_metadata(self) -> Mapping[str, Any]:
        """
        Metadata associated with the client, in the form of an object with string values (max 255 chars). Maximum of 10 metadata properties allowed. Field names (max 255 chars) are alphanumeric and may only include the following special characters: `:,-+=_*?"/\\()<>@ [Tab] [Space]`.
        """
        return pulumi.get(self, "client_metadata")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> str:
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter(name="crossOriginAuth")
    def cross_origin_auth(self) -> bool:
        """
        Whether this client can be used to make cross-origin authentication requests (`true`) or it is not allowed to make such requests (`false`).
        """
        return pulumi.get(self, "cross_origin_auth")

    @property
    @pulumi.getter(name="crossOriginLoc")
    def cross_origin_loc(self) -> str:
        """
        URL of the location in your site where the cross-origin verification takes place for the cross-origin auth flow when performing authentication in your own domain instead of Auth0 Universal Login page.
        """
        return pulumi.get(self, "cross_origin_loc")

    @property
    @pulumi.getter(name="customLoginPage")
    def custom_login_page(self) -> str:
        """
        The content (HTML, CSS, JS) of the custom login page.
        """
        return pulumi.get(self, "custom_login_page")

    @property
    @pulumi.getter(name="customLoginPageOn")
    def custom_login_page_on(self) -> bool:
        """
        Indicates whether a custom login page is to be used.
        """
        return pulumi.get(self, "custom_login_page_on")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of the purpose of the client.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="encryptionKey")
    def encryption_key(self) -> Mapping[str, str]:
        """
        Encryption used for WS-Fed responses with this client.
        """
        return pulumi.get(self, "encryption_key")

    @property
    @pulumi.getter(name="formTemplate")
    def form_template(self) -> str:
        """
        HTML form template to be used for WS-Federation.
        """
        return pulumi.get(self, "form_template")

    @property
    @pulumi.getter(name="grantTypes")
    def grant_types(self) -> Sequence[str]:
        """
        Types of grants that this client is authorized to use.
        """
        return pulumi.get(self, "grant_types")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="initiateLoginUri")
    def initiate_login_uri(self) -> str:
        """
        Initiate login URI. Must be HTTPS or an empty string.
        """
        return pulumi.get(self, "initiate_login_uri")

    @property
    @pulumi.getter(name="isFirstParty")
    def is_first_party(self) -> bool:
        """
        Indicates whether this client is a first-party client.
        """
        return pulumi.get(self, "is_first_party")

    @property
    @pulumi.getter(name="isTokenEndpointIpHeaderTrusted")
    def is_token_endpoint_ip_header_trusted(self) -> bool:
        """
        Indicates whether the token endpoint IP header is trusted. Requires the authentication method to be set to `client_secret_post` or `client_secret_basic`. Setting this property when creating the resource, will default the authentication method to `client_secret_post`. To change the authentication method to `client_secret_basic` use the `ClientCredentials` resource.
        """
        return pulumi.get(self, "is_token_endpoint_ip_header_trusted")

    @property
    @pulumi.getter(name="jwtConfigurations")
    def jwt_configurations(self) -> Sequence['outputs.GetClientJwtConfigurationResult']:
        """
        Configuration settings for the JWTs issued for this client.
        """
        return pulumi.get(self, "jwt_configurations")

    @property
    @pulumi.getter(name="logoUri")
    def logo_uri(self) -> str:
        """
        URL of the logo for the client. Recommended size is 150px x 150px. If none is set, the default badge for the application type will be shown.
        """
        return pulumi.get(self, "logo_uri")

    @property
    @pulumi.getter
    def mobiles(self) -> Sequence['outputs.GetClientMobileResult']:
        """
        Additional configuration for native mobile apps.
        """
        return pulumi.get(self, "mobiles")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of the client. If not provided, `client_id` must be set.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nativeSocialLogins")
    def native_social_logins(self) -> Sequence['outputs.GetClientNativeSocialLoginResult']:
        """
        Configuration settings to toggle native social login for mobile native applications. Once this is set it must stay set, with both resources set to `false` in order to change the `app_type`.
        """
        return pulumi.get(self, "native_social_logins")

    @property
    @pulumi.getter(name="oidcBackchannelLogoutUrls")
    def oidc_backchannel_logout_urls(self) -> Sequence[str]:
        """
        Set of URLs that are valid to call back from Auth0 for OIDC backchannel logout. Currently only one URL is allowed.
        """
        return pulumi.get(self, "oidc_backchannel_logout_urls")

    @property
    @pulumi.getter(name="oidcConformant")
    def oidc_conformant(self) -> bool:
        """
        Indicates whether this client will conform to strict OIDC specifications.
        """
        return pulumi.get(self, "oidc_conformant")

    @property
    @pulumi.getter(name="organizationRequireBehavior")
    def organization_require_behavior(self) -> str:
        """
        Defines how to proceed during an authentication transaction when `organization_usage = "require"`. Can be `no_prompt` (default), `pre_login_prompt` or  `post_login_prompt`.
        """
        return pulumi.get(self, "organization_require_behavior")

    @property
    @pulumi.getter(name="organizationUsage")
    def organization_usage(self) -> str:
        """
        Defines how to proceed during an authentication transaction with regards to an organization. Can be `deny` (default), `allow` or `require`.
        """
        return pulumi.get(self, "organization_usage")

    @property
    @pulumi.getter(name="refreshTokens")
    def refresh_tokens(self) -> Sequence['outputs.GetClientRefreshTokenResult']:
        """
        Configuration settings for the refresh tokens issued for this client.
        """
        return pulumi.get(self, "refresh_tokens")

    @property
    @pulumi.getter(name="requirePushedAuthorizationRequests")
    def require_pushed_authorization_requests(self) -> bool:
        """
        Makes the use of Pushed Authorization Requests mandatory for this client. This feature currently needs to be enabled on the tenant in order to make use of it.
        """
        return pulumi.get(self, "require_pushed_authorization_requests")

    @property
    @pulumi.getter(name="signingKeys")
    def signing_keys(self) -> Sequence[Mapping[str, Any]]:
        """
        List containing a map of the public cert of the signing key and the public cert of the signing key in PKCS7.
        """
        return pulumi.get(self, "signing_keys")

    @property
    @pulumi.getter
    def sso(self) -> bool:
        """
        Applies only to SSO clients and determines whether Auth0 will handle Single Sign-On (true) or whether the identity provider will (false).
        """
        return pulumi.get(self, "sso")

    @property
    @pulumi.getter(name="ssoDisabled")
    def sso_disabled(self) -> bool:
        """
        Indicates whether or not SSO is disabled.
        """
        return pulumi.get(self, "sso_disabled")

    @property
    @pulumi.getter(name="tokenEndpointAuthMethod")
    def token_endpoint_auth_method(self) -> str:
        """
        The authentication method for the token endpoint. Results include `none` (public client without a client secret), `client_secret_post` (client uses HTTP POST parameters), `client_secret_basic` (client uses HTTP Basic). Managing a client's authentication method can be done via the `ClientCredentials` resource.
        """
        return pulumi.get(self, "token_endpoint_auth_method")

    @property
    @pulumi.getter(name="webOrigins")
    def web_origins(self) -> Sequence[str]:
        """
        URLs that represent valid web origins for use with web message response mode.
        """
        return pulumi.get(self, "web_origins")


class AwaitableGetClientResult(GetClientResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClientResult(
            addons=self.addons,
            allowed_clients=self.allowed_clients,
            allowed_logout_urls=self.allowed_logout_urls,
            allowed_origins=self.allowed_origins,
            app_type=self.app_type,
            callbacks=self.callbacks,
            client_aliases=self.client_aliases,
            client_id=self.client_id,
            client_metadata=self.client_metadata,
            client_secret=self.client_secret,
            cross_origin_auth=self.cross_origin_auth,
            cross_origin_loc=self.cross_origin_loc,
            custom_login_page=self.custom_login_page,
            custom_login_page_on=self.custom_login_page_on,
            description=self.description,
            encryption_key=self.encryption_key,
            form_template=self.form_template,
            grant_types=self.grant_types,
            id=self.id,
            initiate_login_uri=self.initiate_login_uri,
            is_first_party=self.is_first_party,
            is_token_endpoint_ip_header_trusted=self.is_token_endpoint_ip_header_trusted,
            jwt_configurations=self.jwt_configurations,
            logo_uri=self.logo_uri,
            mobiles=self.mobiles,
            name=self.name,
            native_social_logins=self.native_social_logins,
            oidc_backchannel_logout_urls=self.oidc_backchannel_logout_urls,
            oidc_conformant=self.oidc_conformant,
            organization_require_behavior=self.organization_require_behavior,
            organization_usage=self.organization_usage,
            refresh_tokens=self.refresh_tokens,
            require_pushed_authorization_requests=self.require_pushed_authorization_requests,
            signing_keys=self.signing_keys,
            sso=self.sso,
            sso_disabled=self.sso_disabled,
            token_endpoint_auth_method=self.token_endpoint_auth_method,
            web_origins=self.web_origins)


def get_client(client_id: Optional[str] = None,
               name: Optional[str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetClientResult:
    """
    Data source to retrieve a specific Auth0 application client by `client_id` or `name`.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_auth0 as auth0

    # An Auth0 Client loaded using its name.
    some_client_by_name = auth0.get_client(name="Name of my Application")
    # An Auth0 Client loaded using its ID.
    some_client_by_id = auth0.get_client(client_id="abcdefghkijklmnopqrstuvwxyz0123456789")
    ```


    :param str client_id: The ID of the client. If not provided, `name` must be set.
    :param str name: The name of the client. If not provided, `client_id` must be set.
    """
    __args__ = dict()
    __args__['clientId'] = client_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('auth0:index/getClient:getClient', __args__, opts=opts, typ=GetClientResult).value

    return AwaitableGetClientResult(
        addons=pulumi.get(__ret__, 'addons'),
        allowed_clients=pulumi.get(__ret__, 'allowed_clients'),
        allowed_logout_urls=pulumi.get(__ret__, 'allowed_logout_urls'),
        allowed_origins=pulumi.get(__ret__, 'allowed_origins'),
        app_type=pulumi.get(__ret__, 'app_type'),
        callbacks=pulumi.get(__ret__, 'callbacks'),
        client_aliases=pulumi.get(__ret__, 'client_aliases'),
        client_id=pulumi.get(__ret__, 'client_id'),
        client_metadata=pulumi.get(__ret__, 'client_metadata'),
        client_secret=pulumi.get(__ret__, 'client_secret'),
        cross_origin_auth=pulumi.get(__ret__, 'cross_origin_auth'),
        cross_origin_loc=pulumi.get(__ret__, 'cross_origin_loc'),
        custom_login_page=pulumi.get(__ret__, 'custom_login_page'),
        custom_login_page_on=pulumi.get(__ret__, 'custom_login_page_on'),
        description=pulumi.get(__ret__, 'description'),
        encryption_key=pulumi.get(__ret__, 'encryption_key'),
        form_template=pulumi.get(__ret__, 'form_template'),
        grant_types=pulumi.get(__ret__, 'grant_types'),
        id=pulumi.get(__ret__, 'id'),
        initiate_login_uri=pulumi.get(__ret__, 'initiate_login_uri'),
        is_first_party=pulumi.get(__ret__, 'is_first_party'),
        is_token_endpoint_ip_header_trusted=pulumi.get(__ret__, 'is_token_endpoint_ip_header_trusted'),
        jwt_configurations=pulumi.get(__ret__, 'jwt_configurations'),
        logo_uri=pulumi.get(__ret__, 'logo_uri'),
        mobiles=pulumi.get(__ret__, 'mobiles'),
        name=pulumi.get(__ret__, 'name'),
        native_social_logins=pulumi.get(__ret__, 'native_social_logins'),
        oidc_backchannel_logout_urls=pulumi.get(__ret__, 'oidc_backchannel_logout_urls'),
        oidc_conformant=pulumi.get(__ret__, 'oidc_conformant'),
        organization_require_behavior=pulumi.get(__ret__, 'organization_require_behavior'),
        organization_usage=pulumi.get(__ret__, 'organization_usage'),
        refresh_tokens=pulumi.get(__ret__, 'refresh_tokens'),
        require_pushed_authorization_requests=pulumi.get(__ret__, 'require_pushed_authorization_requests'),
        signing_keys=pulumi.get(__ret__, 'signing_keys'),
        sso=pulumi.get(__ret__, 'sso'),
        sso_disabled=pulumi.get(__ret__, 'sso_disabled'),
        token_endpoint_auth_method=pulumi.get(__ret__, 'token_endpoint_auth_method'),
        web_origins=pulumi.get(__ret__, 'web_origins'))


@_utilities.lift_output_func(get_client)
def get_client_output(client_id: Optional[pulumi.Input[Optional[str]]] = None,
                      name: Optional[pulumi.Input[Optional[str]]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetClientResult]:
    """
    Data source to retrieve a specific Auth0 application client by `client_id` or `name`.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_auth0 as auth0

    # An Auth0 Client loaded using its name.
    some_client_by_name = auth0.get_client(name="Name of my Application")
    # An Auth0 Client loaded using its ID.
    some_client_by_id = auth0.get_client(client_id="abcdefghkijklmnopqrstuvwxyz0123456789")
    ```


    :param str client_id: The ID of the client. If not provided, `name` must be set.
    :param str name: The name of the client. If not provided, `client_id` must be set.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetTenantResult',
    'AwaitableGetTenantResult',
    'get_tenant',
    'get_tenant_output',
]

@pulumi.output_type
class GetTenantResult:
    """
    A collection of values returned by getTenant.
    """
    def __init__(__self__, allow_organization_name_in_authentication_api=None, allowed_logout_urls=None, customize_mfa_in_postlogin_action=None, default_audience=None, default_directory=None, default_redirection_uri=None, domain=None, enabled_locales=None, flags=None, friendly_name=None, id=None, idle_session_lifetime=None, management_api_identifier=None, picture_url=None, sandbox_version=None, session_cookies=None, session_lifetime=None, sessions=None, support_email=None, support_url=None):
        if allow_organization_name_in_authentication_api and not isinstance(allow_organization_name_in_authentication_api, bool):
            raise TypeError("Expected argument 'allow_organization_name_in_authentication_api' to be a bool")
        pulumi.set(__self__, "allow_organization_name_in_authentication_api", allow_organization_name_in_authentication_api)
        if allowed_logout_urls and not isinstance(allowed_logout_urls, list):
            raise TypeError("Expected argument 'allowed_logout_urls' to be a list")
        pulumi.set(__self__, "allowed_logout_urls", allowed_logout_urls)
        if customize_mfa_in_postlogin_action and not isinstance(customize_mfa_in_postlogin_action, bool):
            raise TypeError("Expected argument 'customize_mfa_in_postlogin_action' to be a bool")
        pulumi.set(__self__, "customize_mfa_in_postlogin_action", customize_mfa_in_postlogin_action)
        if default_audience and not isinstance(default_audience, str):
            raise TypeError("Expected argument 'default_audience' to be a str")
        pulumi.set(__self__, "default_audience", default_audience)
        if default_directory and not isinstance(default_directory, str):
            raise TypeError("Expected argument 'default_directory' to be a str")
        pulumi.set(__self__, "default_directory", default_directory)
        if default_redirection_uri and not isinstance(default_redirection_uri, str):
            raise TypeError("Expected argument 'default_redirection_uri' to be a str")
        pulumi.set(__self__, "default_redirection_uri", default_redirection_uri)
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if enabled_locales and not isinstance(enabled_locales, list):
            raise TypeError("Expected argument 'enabled_locales' to be a list")
        pulumi.set(__self__, "enabled_locales", enabled_locales)
        if flags and not isinstance(flags, list):
            raise TypeError("Expected argument 'flags' to be a list")
        pulumi.set(__self__, "flags", flags)
        if friendly_name and not isinstance(friendly_name, str):
            raise TypeError("Expected argument 'friendly_name' to be a str")
        pulumi.set(__self__, "friendly_name", friendly_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if idle_session_lifetime and not isinstance(idle_session_lifetime, float):
            raise TypeError("Expected argument 'idle_session_lifetime' to be a float")
        pulumi.set(__self__, "idle_session_lifetime", idle_session_lifetime)
        if management_api_identifier and not isinstance(management_api_identifier, str):
            raise TypeError("Expected argument 'management_api_identifier' to be a str")
        pulumi.set(__self__, "management_api_identifier", management_api_identifier)
        if picture_url and not isinstance(picture_url, str):
            raise TypeError("Expected argument 'picture_url' to be a str")
        pulumi.set(__self__, "picture_url", picture_url)
        if sandbox_version and not isinstance(sandbox_version, str):
            raise TypeError("Expected argument 'sandbox_version' to be a str")
        pulumi.set(__self__, "sandbox_version", sandbox_version)
        if session_cookies and not isinstance(session_cookies, list):
            raise TypeError("Expected argument 'session_cookies' to be a list")
        pulumi.set(__self__, "session_cookies", session_cookies)
        if session_lifetime and not isinstance(session_lifetime, float):
            raise TypeError("Expected argument 'session_lifetime' to be a float")
        pulumi.set(__self__, "session_lifetime", session_lifetime)
        if sessions and not isinstance(sessions, list):
            raise TypeError("Expected argument 'sessions' to be a list")
        pulumi.set(__self__, "sessions", sessions)
        if support_email and not isinstance(support_email, str):
            raise TypeError("Expected argument 'support_email' to be a str")
        pulumi.set(__self__, "support_email", support_email)
        if support_url and not isinstance(support_url, str):
            raise TypeError("Expected argument 'support_url' to be a str")
        pulumi.set(__self__, "support_url", support_url)

    @property
    @pulumi.getter(name="allowOrganizationNameInAuthenticationApi")
    def allow_organization_name_in_authentication_api(self) -> bool:
        """
        Whether to accept an organization name instead of an ID on auth endpoints.
        """
        return pulumi.get(self, "allow_organization_name_in_authentication_api")

    @property
    @pulumi.getter(name="allowedLogoutUrls")
    def allowed_logout_urls(self) -> Sequence[str]:
        """
        URLs that Auth0 may redirect to after logout.
        """
        return pulumi.get(self, "allowed_logout_urls")

    @property
    @pulumi.getter(name="customizeMfaInPostloginAction")
    def customize_mfa_in_postlogin_action(self) -> bool:
        """
        Whether to enable flexible factors for MFA in the PostLogin action.
        """
        return pulumi.get(self, "customize_mfa_in_postlogin_action")

    @property
    @pulumi.getter(name="defaultAudience")
    def default_audience(self) -> str:
        """
        API Audience to use by default for API Authorization flows. This setting is equivalent to appending the audience to every authorization request made to the tenant for every application.
        """
        return pulumi.get(self, "default_audience")

    @property
    @pulumi.getter(name="defaultDirectory")
    def default_directory(self) -> str:
        """
        Name of the connection to be used for Password Grant exchanges. Options include `auth0-adldap`, `ad`, `auth0`, `email`, `sms`, `waad`, and `adfs`.
        """
        return pulumi.get(self, "default_directory")

    @property
    @pulumi.getter(name="defaultRedirectionUri")
    def default_redirection_uri(self) -> str:
        """
        The default absolute redirection URI. Must be HTTPS or an empty string.
        """
        return pulumi.get(self, "default_redirection_uri")

    @property
    @pulumi.getter
    def domain(self) -> str:
        """
        Your Auth0 domain name.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="enabledLocales")
    def enabled_locales(self) -> Sequence[str]:
        """
        Supported locales for the user interface. The first locale in the list will be used to set the default locale.
        """
        return pulumi.get(self, "enabled_locales")

    @property
    @pulumi.getter
    def flags(self) -> Sequence['outputs.GetTenantFlagResult']:
        """
        Configuration settings for tenant flags.
        """
        return pulumi.get(self, "flags")

    @property
    @pulumi.getter(name="friendlyName")
    def friendly_name(self) -> str:
        """
        Friendly name for the tenant.
        """
        return pulumi.get(self, "friendly_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="idleSessionLifetime")
    def idle_session_lifetime(self) -> float:
        """
        Number of hours during which a session can be inactive before the user must log in again.
        """
        return pulumi.get(self, "idle_session_lifetime")

    @property
    @pulumi.getter(name="managementApiIdentifier")
    def management_api_identifier(self) -> str:
        """
        The identifier value of the built-in Management API resource server, which can be used as an audience when configuring client grants.
        """
        return pulumi.get(self, "management_api_identifier")

    @property
    @pulumi.getter(name="pictureUrl")
    def picture_url(self) -> str:
        """
        URL of logo to be shown for the tenant. Recommended size is 150px x 150px. If no URL is provided, the Auth0 logo will be used.
        """
        return pulumi.get(self, "picture_url")

    @property
    @pulumi.getter(name="sandboxVersion")
    def sandbox_version(self) -> str:
        """
        Selected sandbox version for the extensibility environment, which allows you to use custom scripts to extend parts of Auth0's functionality.
        """
        return pulumi.get(self, "sandbox_version")

    @property
    @pulumi.getter(name="sessionCookies")
    def session_cookies(self) -> Sequence['outputs.GetTenantSessionCookyResult']:
        """
        Alters behavior of tenant's session cookie. Contains a single `mode` property.
        """
        return pulumi.get(self, "session_cookies")

    @property
    @pulumi.getter(name="sessionLifetime")
    def session_lifetime(self) -> float:
        """
        Number of hours during which a session will stay valid.
        """
        return pulumi.get(self, "session_lifetime")

    @property
    @pulumi.getter
    def sessions(self) -> Sequence['outputs.GetTenantSessionResult']:
        """
        Sessions related settings for the tenant.
        """
        return pulumi.get(self, "sessions")

    @property
    @pulumi.getter(name="supportEmail")
    def support_email(self) -> str:
        """
        Support email address for authenticating users.
        """
        return pulumi.get(self, "support_email")

    @property
    @pulumi.getter(name="supportUrl")
    def support_url(self) -> str:
        """
        Support URL for authenticating users.
        """
        return pulumi.get(self, "support_url")


class AwaitableGetTenantResult(GetTenantResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTenantResult(
            allow_organization_name_in_authentication_api=self.allow_organization_name_in_authentication_api,
            allowed_logout_urls=self.allowed_logout_urls,
            customize_mfa_in_postlogin_action=self.customize_mfa_in_postlogin_action,
            default_audience=self.default_audience,
            default_directory=self.default_directory,
            default_redirection_uri=self.default_redirection_uri,
            domain=self.domain,
            enabled_locales=self.enabled_locales,
            flags=self.flags,
            friendly_name=self.friendly_name,
            id=self.id,
            idle_session_lifetime=self.idle_session_lifetime,
            management_api_identifier=self.management_api_identifier,
            picture_url=self.picture_url,
            sandbox_version=self.sandbox_version,
            session_cookies=self.session_cookies,
            session_lifetime=self.session_lifetime,
            sessions=self.sessions,
            support_email=self.support_email,
            support_url=self.support_url)


def get_tenant(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTenantResult:
    """
    Use this data source to access information about the tenant this provider is configured to access.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_auth0 as auth0

    my_tenant = auth0.get_tenant()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('auth0:index/getTenant:getTenant', __args__, opts=opts, typ=GetTenantResult).value

    return AwaitableGetTenantResult(
        allow_organization_name_in_authentication_api=pulumi.get(__ret__, 'allow_organization_name_in_authentication_api'),
        allowed_logout_urls=pulumi.get(__ret__, 'allowed_logout_urls'),
        customize_mfa_in_postlogin_action=pulumi.get(__ret__, 'customize_mfa_in_postlogin_action'),
        default_audience=pulumi.get(__ret__, 'default_audience'),
        default_directory=pulumi.get(__ret__, 'default_directory'),
        default_redirection_uri=pulumi.get(__ret__, 'default_redirection_uri'),
        domain=pulumi.get(__ret__, 'domain'),
        enabled_locales=pulumi.get(__ret__, 'enabled_locales'),
        flags=pulumi.get(__ret__, 'flags'),
        friendly_name=pulumi.get(__ret__, 'friendly_name'),
        id=pulumi.get(__ret__, 'id'),
        idle_session_lifetime=pulumi.get(__ret__, 'idle_session_lifetime'),
        management_api_identifier=pulumi.get(__ret__, 'management_api_identifier'),
        picture_url=pulumi.get(__ret__, 'picture_url'),
        sandbox_version=pulumi.get(__ret__, 'sandbox_version'),
        session_cookies=pulumi.get(__ret__, 'session_cookies'),
        session_lifetime=pulumi.get(__ret__, 'session_lifetime'),
        sessions=pulumi.get(__ret__, 'sessions'),
        support_email=pulumi.get(__ret__, 'support_email'),
        support_url=pulumi.get(__ret__, 'support_url'))


@_utilities.lift_output_func(get_tenant)
def get_tenant_output(opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTenantResult]:
    """
    Use this data source to access information about the tenant this provider is configured to access.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_auth0 as auth0

    my_tenant = auth0.get_tenant()
    ```
    """
    ...
